@@ -1,7 +1,7 @@
 """Support for Aquanot® devices."""
 
 from dataclasses import dataclass
-from enum import IntEnum, IntFlag, StrEnum
+from enum import Enum, IntEnum, IntFlag
 
 from .battery import ZControlBatteryDevice
 from .float import ZControlFloatDevice
@@ -13,9 +13,12 @@ from ..utils import AttributeMap
 class AquanotFit508(ZControlBatteryDevice, ZControlFloatDevice, ZControlPumpDevice):
     """Support for fetching the status of Aquanot® Fit 508 devices."""
 
+    MODEL = "Aquanot® Fit 508"
+
     def _process_attrs(self, attrs: AttributeMap) -> None:
         # ZControlDevice
         self.device_id = attrs.get(self._Attribute.DEVICE_ID)
+        self.serial_number = self.device_id
         self.firmware_version = attrs.get(self._Attribute.FIRMWARE_VERSION)
         self.system_uptime = attrs.get_float(self._Attribute.SYSTEM_UPTIME, 0.1)
         self.is_self_test_running = attrs.get_bool_from_bitmask(
@@ -90,7 +93,7 @@ class AquanotFit508(ZControlBatteryDevice, ZControlFloatDevice, ZControlPumpDevi
         """Acknowledges all faults and resets the device."""
         self.connection.fetch_resource("ackfaults.cgi")
 
-    class _Attribute(StrEnum):
+    class _Attribute(str, Enum):
 
         DEVICE_ID = "deviceid"
         FIRMWARE_VERSION = "firm"
