@@ -1,7 +1,8 @@
 """Basic support for ZControl® devices equipped with batteries."""
 
 from dataclasses import dataclass
-from enum import StrEnum
+from enum import Enum
+from typing import Optional
 from .basic import ZControlDevice
 
 
@@ -13,31 +14,31 @@ class ZControlBatteryDevice(ZControlDevice):
     class Battery:
         """Defines a battery."""
 
-        class Type(StrEnum):
+        class Type(str, Enum):
             """Defines the battery types."""
 
             BACKUP = "Backup"
 
-        voltage: float | None = None
+        voltage: Optional[float] = None
         """The battery's voltage in volts."""
 
-        current: float | None = None
+        current: Optional[float] = None
         """The battery's current in amps."""
 
-        is_charging: bool | None = None
+        is_charging: Optional[bool] = None
         """Whether or not the battery is charging."""
 
-        is_low: bool | None = None
+        is_low: Optional[bool] = None
         """Whether or not the battery is low."""
 
-        is_missing: bool | None = None
+        is_missing: Optional[bool] = None
         """Whether or not the battery is missing."""
 
-        is_bad: bool | None = None
+        is_bad: Optional[bool] = None
         """Whether or not the battery is bad."""
 
     batteries: dict[Battery.Type: Battery] = None
     """The device's batteries by type."""
 
-    is_primary_power_missing: bool | None = None
+    is_primary_power_missing: Optional[bool] = None
     """Whether or not the device's primary power source is missing."""
